@@ -3,7 +3,7 @@
 #' @usage dataset(scientificname = NULL, taxonid = NULL, datasetid = NULL,
 #'   nodeid = NULL, areaid = NULL, startdate = NULL, enddate = NULL,
 #'   startdepth = NULL, enddepth = NULL, geometry = NULL, redlist = NULL,
-#'   verbose = FALSE)
+#'   exclude = NULL, verbose = FALSE)
 #' @param scientificname the scientific name.
 #' @param taxonid the taxon identifier (WoRMS AphiaID).
 #' @param datasetid the dataset identifier.
@@ -15,6 +15,7 @@
 #' @param enddepth the maximum depth below the sea surface.
 #' @param geometry a WKT geometry string.
 #' @param redlist include only IUCN Red List species.
+#' @param exclude quality flags to be excluded from the results.
 #' @param verbose logical. Optional parameter to enable verbose logging (default = \code{FALSE}).
 #' @return The datasets.
 #' @examples
@@ -34,6 +35,7 @@ dataset <- function(
   enddepth = NULL,
   geometry = NULL,
   redlist = NULL,
+  exclude = NULL,
   verbose = FALSE
 ) {
 
@@ -57,6 +59,7 @@ dataset <- function(
       enddepth = enddepth,
       geometry = geometry,
       redlist = handle_logical(redlist),
+      exclude = handle_vector(exclude),
       skip = skip,
       size = page_size()
     )
@@ -75,8 +78,8 @@ dataset <- function(
     skip <- skip + page_size()
 
     if (!is.null(res$results) && is.data.frame(res$results) && nrow(res$results) > 0) {
-      res$results$node_id <- apply(res$results$node, 1, function(x) { return(x["id"]) })
-      res$results$node_name <- apply(res$results$node, 1, function(x) { return(x["name"]) })
+      res$results$node_id <- sapply(res$results$nodes, function(x) { return(paste0(x$id, collapse = ",")) })
+      res$results$node_name <- sapply(res$results$nodes, function(x) { return(paste0(x$name, collapse = ",")) })
       res$results <- res$results[,!(names(res$results) %in% c("node", "feed", "institutes", "contacts"))]
       result_list[[i]] <- res$results
       fetched <- fetched + nrow(res$results)
